@@ -236,6 +236,7 @@ metaGE.heatmap <- function(Data, Prefix='Z.', EnvGroups=NULL, QTLsVarName=NULL,R
 #' @export
 #' @importFrom qqman manhattan
 #' @importFrom ggrepel geom_label_repel
+#' @importFrom grDevices col2rgb rgb
 #' @examples
 #' require(dplyr)
 #' # Import the data
@@ -351,7 +352,7 @@ metaGE.manhattan <- function(Data, VarName, Threshold=NULL,SigZones=NULL,Score =
     # Add vertical lines to annotate markers
     if(!is.null(AnnotateMarkers)){
       manhattan <- manhattan + geom_segment(data = AnnotateMarker_info,aes(x = .data$POScum, xend=.data$POScum,y=min(-log10(don$VarToPlot)), yend=Inf),
-                                            linewidth=0.8,color= yarrr::transparent("red2", trans.val = .3),linetype=2) 
+                                            linewidth=0.8,color= (rgb(t(col2rgb("red2")) / 255, alpha = 0.3)),linetype=2) 
     }
     # Add a threshold
     if(!is.null(Threshold)){
@@ -403,7 +404,7 @@ metaGE.manhattan <- function(Data, VarName, Threshold=NULL,SigZones=NULL,Score =
     # Add vertical lines to annotate markers
     if(!is.null(AnnotateMarkers)){
       manhattan <- manhattan + geom_segment(data = AnnotateMarker_info,aes(x = .data$POScum, xend=.data$POScum,y=min(don$VarToPlot), yend=Inf),
-                                            linewidth=0.8,color= yarrr::transparent("red2", trans.val = .3),linetype=2) 
+                                            linewidth=0.8,color= (rgb(t(col2rgb("red2")) / 255, alpha = 0.3)),linetype=2) 
     }
     # Add a threshold
     if(!is.null(Threshold)){
